# NLP Test Data

## Translators

## MedCAT

The pt_notes.csv, the notevents.csv and the patients.csv files were obtained from the [MedCAT Tutorial Data](https://github.com/CogStack/MedCAT/tree/master/tutorial/data).
Any files with more than 500 lines were truncated to the first 500.
